float4x4 modelViewProjMatrix;
float4x4 modelMatrix;
float4x4 modelMatrixInverse;

struct TrafoInput
{
    float4 pos		: POSITION;
    float3 normal	: NORMAL;
    float2 tex		: TEXCOORD0;
};

struct TrafoOutput
{
    float4 pos		: POSITION;
    float3 normal	: TEXCOORD2;
    float2 tex		: TEXCOORD0;
    float4 worldPos	: TEXCOORD1;
};

TrafoOutput vsTrafo(TrafoInput input)
{
	TrafoOutput output = (TrafoOutput)0;
	output.pos = mul(input.pos, modelViewProjMatrix);
	output.worldPos = mul(input.pos, modelMatrix);
	output.normal = mul(modelMatrixInverse, float4(input.normal.xyz, 0.0));
	output.tex = input.tex;
	return output;
}

texture kdMap;
sampler2D kdMapSampler =	sampler_state{	
		texture = < kdMap >;
		MinFilter = LINEAR;
		MagFilter = LINEAR;
		MipFilter = LINEAR;
		AddressU  = Wrap;
		AddressV  = Wrap;
		};


float4 psDiffuse(TrafoOutput input) : COLOR0
{
	return abs(input.normal.y) * tex2D(kdMapSampler, input.tex);
}

technique show
{
    pass ExamplePass
    {
        VertexShader = compile vs_2_0 vsTrafo();
        PixelShader  = compile ps_2_0 psDiffuse();
    }
}


struct QuadInput
{
	float4  pos			: POSITION;
	float2  tex			: TEXCOORD0;
};

struct QuadOutput
{
	float4 pos				: POSITION;
	float2 tex				: TEXCOORD0;
	float3 viewDir			: TEXCOORD1;
};

float4x4 rotProjMatrixInverse;

QuadOutput vsQuad(QuadInput input)
{
	QuadOutput output = (QuadOutput)0;

	output.pos = input.pos;
    float4 hWorldPosMinusEye = mul(input.pos, 	rotProjMatrixInverse);
    hWorldPosMinusEye /= hWorldPosMinusEye.w;
    output.viewDir = hWorldPosMinusEye.xyz;
    output.pos.z = 1; // minden mg
    output.tex = input.tex;
    return output;
};

textureCUBE environmentCubeTexture;
samplerCUBE environmentCubeSampler = sampler_state
{
	texture = <environmentCubeTexture>;
	MipFilter = Linear;
	MagFilter = Linear;
	MinFilter = Linear;
};

float4 psEnvironment(QuadOutput input) : COLOR0
{
	return 	texCUBE(environmentCubeSampler, 	input.viewDir);
};

technique environment
{
	pass P0
	{
		VertexShader = compile vs_3_0 			vsQuad();
		PixelShader = compile ps_3_0 			psEnvironment();
	}	
};
